########################################################################

# Analysis for toad CMR

########################################################################

#Note:DS_combined=dry season;WS_combined=wet season

#Load package
library(Rcapture)

#Read the data
DS_combined<-read.csv("DS_combined.inp.csv")
WS_combined<-read.csv("WS_combined.inp.csv")

#Use the closedp.t function for fitting 12 combination models incorporating 
#different sources of variation in capture probability (t = time varying p; 
#b = behavioural response to capture changes in p; and h = heterogeneity 
#in p for unknown reasons) that may have affected capture probability

#dfreq set as FALSE indicates that the data frame (e.g., DS_combined) has one row per unit
#dfreq set as TRUE, negative eta parameters in Chao's lower bound models are set to zero

est_DScombined<-closedp(DS_combined, dfreq=FALSE, neg=TRUE)
est_WScombined<-closedp(WS_combined, dfreq=FALSE, neg=TRUE)

#Use the uifit function for discriminating between close estimators by producing 
#fit statistics for each model for the number of new captures on each occasion 
#and if the experiment was continued

uifit(est_DScombined)
uifit(est_WScombined)

#Use the closedpCI.t function to construct Multinomial profile confidence intervals 
#Obs.: this analyses can only be ran for the null, time varying or heterogeneity models 
#("M0","Mt","Mh","Mth")

closedpCI.t(DS_combined, m=c("Mt"))
profileCI(DS_combined, m="Mt",h="Poisson", a=2)

closedpCI.t(WS_combined, m=c("Mt"))
profileCI(WS_combined, m="Mt",h="Poisson", a=2)


