########################################################################

# Analysis for toad movement with climatic variables

########################################################################

############# ANALYSIS 1: distance and climatic variables
library(lme4)
library(car)

# Wet Season
attach(CWS_1Bi)
WS1 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CWS_1Bi)
summary(WS1)
Anova(WS1) # *hab

WS2 <- lmer(distance~ Sex+hab + precip +WC+RH+BP+(1 | individual), data=CWS_1Bi)
summary(WS2)
Anova(WS2) # *hab

WS3 <- lmer(distance~ Sex+hab + precip+RH+BP+(1 | individual), data=CWS_1Bi)
summary(WS3)
Anova(WS3) #hab **

# SUMMARY: distance~climate not statistically significant

#5+ days
attach(CWS_1Bii)
yes <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CWS_1Bii)
summary(yes)
anova(yes) #hab *

yes1 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+(1 | individual), data=CWS_1Bii)
summary(yes1)
anova(yes1) #hab *

yes2 <- lmer(distance~ Sex+hab + precip +WC+RH+BP+(1 | individual), data=CWS_1Bii)
summary(yes2)
anova(yes2) #hab *

# SUMMARY: distance~climate not statistically significant

# Dry Season
attach(CDS_1Bi)
DS1 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bi)
summary(DS1)
Anova(DS1) 

DS2 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bi)
summary(DS2)
Anova(DS2) 

DS3 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bi)
summary(DS3)
Anova(DS3)

# 5+ days
attach(CDS_1Bii)
ok <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bii)
summary(ok)
Anova(ok) 

ok1 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bii)
summary(ok1)
Anova(ok1) 

ok2 <- lmer(distance~ Sex+hab + precip +TP+WC+RH+BP+(1 | individual), data=CDS_1Bii)
summary(ok2)
Anova(ok2)


############ ANALYSIS 2: movement and climatic variables

#### Wet Season
attach(CWS_1Ei)
model<-glm(active~precip+WC+TP+RH+BP,data=CWS_1Ei,family = "binomial")
summary(model)

bestmodel<-step(model,direction = "both")

#AIC 222.18
model1.1<-glm(active~precip+WC+TP+RH+BP,data=CWS_1Ei,family = "binomial")
summary(model1.1)

#AIC 220.22
model1.2<-glm(active~WC + TP + RH + BP,data=CWS_1Ei,family = "binomial")
summary(model1.2)

#AIC 218.83
model1.3<-glm(active~WC + TP + BP,data=CWS_1Ei,family = "binomial")
summary(model1.3)

#AIC 217.29
model1.4<-glm(active~WC + TP,data=CWS_1Ei,family = "binomial")
summary(model1.4) 

#AIC 216.92
model1.5<-glm(active~WC,data=CWS_1Ei,family = "binomial")
summary(model1.5) 

library(MuMIn)
out.put<-model.sel(model,model1.1,model1.2,model1.3,model1.4,model1.5)
out.put #model 1.5 is (0.437/0.275)=1.58 times more likely to explain the variation

Anova(model1.5)
pp<- sum(resid(model1.5, type = "pearson")^2) 
1 - pchisq(pp, model1.5$df.resid) #0.9716956 #doesn't approach 2, therefore can be said is good model

# SUMMARY: WIND CHILL BEST EXPLAIN MOVEMENT/NON-MOVEMENT DURING THE WET SEASON

boxplot(WC~active,ylab='Wind Chill',xlab='Active')

##### dry season
attach(CDS_1Ei)
model2<-glm(active~Precip+WC+TP+RH+BP,data=CDS_1Ei,family = "binomial")
summary(model2) #WC and TP ***

bestmodel2<-step(model2,direction = "both")

# AIC 172.62
model2.1<-glm(active~Precip + WC + TP + RH + BP,data=CDS_1Ei,family = "binomial")
summary(model2.1) #WC and TP ***

# AIC 170.62
model2.2<-glm(active~WC + TP + RH + BP,data=CDS_1Ei,family = "binomial")
summary(model2.2) #WC and TP ***

# AIC 168.67
model2.3<-glm(active~WC + TP + RH,data=CDS_1Ei,family = "binomial")
summary(model2.3) #WC and TP ***

library(MuMIn)
out.put<-model.sel(model2,model2.1,model2.2,model2.3)
out.put #model 2.3 is (0.622/0.223)=2.8 times more likely to explain the variation

Anova(model2.3) 
pp<- sum(resid(model2.1, type = "pearson")^2) 
1 - pchisq(pp, model2.1$df.resid) #0.3776313, therefore a "good" fit

# SUMMARY: WIND CHILL AND TEMPERATURE BEST EXPLAIN MOVEMENT/NON-MOVEMENT DURING THE DRY SEASON

boxplot(WC~active,ylab='Wind Chill',xlab='Active')
boxplot(TP~active,ylab='Temperature',xlab='Active')


##### ANALYSIS 3: time of day
attach(Cdayni)

nd<-manova(cbind(sex,distance,precip,WS,TP,WC,RH,HI,BP)~TOD,data=Cdayni)
summary(nd)
summary.aov(nd) #WS, TP, WC, RH, HI and BP significantly (***) different between night and day

nd1<-manova(cbind(WS,TP,WC,RH,HI,BP)~TOD,data=Cdayni)
summary(nd1)
summary.aov(nd1) #WS, TP, WC, RH, HI and BP significantly (***) different between night and day

# SUMMARY: CLIMATIC VARIABLES SIGNFICANTLY DIFFERENT BETWEEN NIGHT AND DAY

dn<-lmer(distance~sex+TOD+precip+WS+TP+WC+RH+HI+BP+(1|individual),data = Cdayni)
summary(dn)
Anova(dn) #TOD*

dn1<-lmer(distance~sex+TOD+precip+WS+WC+RH+BP+(1|individual),data = Cdayni)
summary(dn1)
Anova(dn1) #TOD*, RH .

dn2<-lmer(distance~sex+TOD+precip+WS+RH+(1|individual),data = Cdayni)
summary(dn2)
Anova(dn2) #TOD **, RH . 

dn3<-lmer(distance~sex+TOD+WS+RH+(1|individual),data = Cdayni)
summary(dn3)
Anova(dn3) #TOD **, RH . 

# SUMMARY: TOD STATISTICALLY SIGNIFICANT FOR DISTANCE (RH IS CLOSE)

cor.test(precip,distance,method = "spearman",data=Cdayni) #0.4963
cor.test(TP,distance,method = "spearman",data=Cdayni) #0.289
cor.test(WC,distance,method = "spearman",data=Cdayni) # 0.2121
cor.test(RH,distance,method = "spearman",data=Cdayni) #0.5685
cor.test(BP,distance,method = "spearman",data=Cdayni) #0.7246

qqnorm(sqrt(precip),main="QQ plot of precip data",pch=19)
qqline(precip)
qqnorm(TP,main="QQ plot of TP data",pch=19)
qqline(TP)
qqnorm(WC,main="QQ plot of WC data",pch=19)
qqline(WC)
qqnorm(RH,main="QQ plot of RH data",pch=19)
qqline(RH)
qqnorm(BP,main="QQ plot of BP data",pch=19)
qqline(BP)

###### ANALYSIS 5: exploration of climatic variables
library(ggfortify)
library(ggplot2)
df <- Cdayni[c(11,13,14,15,17)]
autoplot(prcomp(df)) #plot of PCA
pca<-autoplot(prcomp(df), data = Cdayni, colour = 'TOD',shape = 'TOD',
              loadings = TRUE, loadings.colour = 'black',
              loadings.label = TRUE, loadings.label.size = 3,legend.title="Time of Day")
pca

# SUMMARY:Samples (night or day) separated by WC AND TP. WC, TP and BP are all positively associated.
# (cont.) TP, WC and BP mostly associated with daytime samples, RH with night.